==> mypackage-mylang-1.0.3.tgz: package/index.js <==
const languageMaster =
    [
        {
            "languageid": 1,
            "language": "English",
            "languagecode": "en"
        },
        {
            "languageid": 2,
            "language": "Hindi",
            "languagecode": "hi"
        },
        {
            "languageid": 3,
            "language": "Marathi",
            "languagecode": "ar"
        },
        {
            "languageid": 4,
            "language": "Gujarati",
            "languagecode": "gu"
        },
        {
            "languageid": 5,
            "language": "Tamil",
            "languagecode": "ta"
        },
        {
            "languageid": 6,
            "language": "Bengali",
            "languagecode": "bn"
        },
        {
            "languageid": 7,
            "language": "Urdu",
            "languagecode": "ur"
        },
        {
            "languageid": 8,
            "language": "Spanish",
            "languagecode": "es"
        },
        {
            "languageid": 9,
            "language": "Marathi",
            "languagecode": "mr"
        },
        {
            "languageid": 10,
            "language": "Telugu",
            "languagecode": "te"
        },
        {
            "languageid": 11,
            "language": "French",
            "languagecode": "fr"
        },
        {
            "languageid": 12,
            "language": "Russian",
            "languagecode": "ru"
        },
        {
            "languageid": 13,
            "language": "Japanese",
            "languagecode": "ja"
        },
        {
            "languageid": 14,
            "language": "German",
            "languagecode": "de"
        },
        {
            "languageid": 15,
            "language": "Afrikaans ",
            "languagecode": "af"
        },
        {
            "languageid": 16,
            "language": "Albanian ",
            "languagecode": "sq"
        },
        {
            "languageid": 17,
            "language": "Amharic ",
            "languagecode": "am"
        },
        {
            "languageid": 18,
            "language": "Armenian ",
            "languagecode": "hy"
        },
        {
            "languageid": 19,
            "language": "Assamese ",
            "languagecode": "as"
        },
        {
            "languageid": 20,
            "language": "Aymara ",
            "languagecode": "ay"
        },
        {
            "languageid": 21,
            "language": "Azerbaijani ",
            "languagecode": "az"
        },
        {
            "languageid": 22,
            "language": "Bambara ",
            "languagecode": "bm"
        },
        {
            "languageid": 23,
            "language": "Basque ",
            "languagecode": "eu"
        },
        {
            "languageid": 24,
            "language": "Belarusian ",
            "languagecode": "be"
        },
        {
            "languageid": 25,
            "language": "Bhojpuri ",
            "languagecode": "bho"
        },
        {
            "languageid": 26,
            "language": "Bosnian ",
            "languagecode": "bs"
        },
        {
            "languageid": 27,
            "language": "Bulgarian ",
            "languagecode": "bg"
        },
        {
            "languageid": 28,
            "language": "Catalan ",
            "languagecode": "ca"
        },
        {
            "languageid": 29,
            "language": "Cebuano ",
            "languagecode": "ceb"
        },
        {
            "languageid": 30,
            "language": "Corsican ",
            "languagecode": "co"
        },
        {
            "languageid": 31,
            "language": "Croatian ",
            "languagecode": "hr"
        },
        {
            "languageid": 32,
            "language": "Czech ",
            "languagecode": "cs"
        },
        {
            "languageid": 33,
            "language": "Danish ",
            "languagecode": "da"
        },
        {
            "languageid": 34,
            "language": "Dhivehi ",
            "languagecode": "dv"
        },
        {
            "languageid": 35,
            "language": "Dogri ",
            "languagecode": "doi"
        },
        {
            "languageid": 36,
            "language": "Dutch ",
            "languagecode": "nl"
        },
        {
            "languageid": 37,
            "language": "Esperanto ",
            "languagecode": "eo"
        },
        {
            "languageid": 38,
            "language": "Estonian ",
            "languagecode": "et"
        },
        {
            "languageid": 39,
            "language": "Ewe ",
            "languagecode": "ee"
        },
        {
            "languageid": 40,
            "language": "Filipino Tagalog) ",
            "languagecode": "fil"
        },
        {
            "languageid": 41,
            "language": "Finnish ",
            "languagecode": "fi"
        },
        {
            "languageid": 42,
            "language": "Frisian ",
            "languagecode": "fy"
        },
        {
            "languageid": 43,
            "language": "Galician ",
            "languagecode": "gl"
        },
        {
            "languageid": 44,
            "language": "Georgian ",
            "languagecode": "ka"
        },
        {
            "languageid": 45,
            "language": "Greek ",
            "languagecode": "el"
        },
        {
            "languageid": 46,
            "language": "Guarani ",
            "languagecode": "gn"
        },
        {
            "languageid": 47,
            "language": "Haitian Creole ",
            "languagecode": "ht"
        },
        {
            "languageid": 48,
            "language": "Hausa ",
            "languagecode": "ha"
        },
        {
            "languageid": 49,
            "language": "Hawaiian ",
            "languagecode": "haw"
        },
        {
            "languageid": 50,
            "language": "Hebrew ",
            "languagecode": "he or iw"
        },
        {
            "languageid": 51,
            "language": "Hmong ",
            "languagecode": "hmn"
        },
        {
            "languageid": 52,
            "language": "Hungarian ",
            "languagecode": "hu"
        },
        {
            "languageid": 53,
            "language": "Icelandic ",
            "languagecode": "is"
        },
        {
            "languageid": 54,
            "language": "Igbo ",
            "languagecode": "ig"
        },
        {
            "languageid": 55,
            "language": "Ilocano ",
            "languagecode": "ilo"
        },
        {
            "languageid": 56,
            "language": "Indonesian ",
            "languagecode": "id"
        },
        {
            "languageid": 57,
            "language": "Irish ",
            "languagecode": "ga"
        },
        {
            "languageid": 58,
            "language": "Italian ",
            "languagecode": "it"
        },
        {
            "languageid": 59,
            "language": "Javanese ",
            "languagecode": "jv or jw"
        },
        {
            "languageid": 60,
            "language": "Kannada ",
            "languagecode": "kn"
        },
        {
            "languageid": 61,
            "language": "Kazakh ",
            "languagecode": "kk"
        },
        {
            "languageid": 62,
            "language": "Khmer ",
            "languagecode": "km"
        },
        {
            "languageid": 63,
            "language": "Kinyarwanda ",
            "languagecode": "rw"
        },
        {
            "languageid": 64,
            "language": "Konkani ",
            "languagecode": "gom"
        },
        {
            "languageid": 65,
            "language": "Korean ",
            "languagecode": "ko"
        },
        {
            "languageid": 66,
            "language": "Krio ",
            "languagecode": "kri"
        },
        {
            "languageid": 67,
            "language": "Kurdish ",
            "languagecode": "ku"
        },
        {
            "languageid": 68,
            "language": "Kurdish Sorani) ",
            "languagecode": "ckb"
        },
        {
            "languageid": 69,
            "language": "Kyrgyz ",
            "languagecode": "ky"
        },
        {
            "languageid": 70,
            "language": "Lao ",
            "languagecode": "lo"
        },
        {
            "languageid": 71,
            "language": "Latin ",
            "languagecode": "la"
        },
        {
            "languageid": 72,
            "language": "Latvian ",
            "languagecode": "lv"
        },
        {
            "languageid": 73,
            "language": "Lingala ",
            "languagecode": "ln"
        },
        {
            "languageid": 74,
            "language": "Lithuanian ",
            "languagecode": "lt"
        },
        {
            "languageid": 75,
            "language": "Luganda ",
            "languagecode": "lg"
        },
        {
            "languageid": 76,
            "language": "Luxembourgish ",
            "languagecode": "lb"
        },
        {
            "languageid": 77,
            "language": "Macedonian ",
            "languagecode": "mk"
        },
        {
            "languageid": 78,
            "language": "Maithili ",
            "languagecode": "mai"
        },
        {
            "languageid": 79,
            "language": "Malagasy ",
            "languagecode": "mg"
        },
        {
            "languageid": 80,
            "language": "Malay ",
            "languagecode": "ms"
        },
        {
            "languageid": 81,
            "language": "Malayalam ",
            "languagecode": "ml"
        },
        {
            "languageid": 82,
            "language": "Maltese ",
            "languagecode": "mt"
        },
        {
            "languageid": 83,
            "language": "Maori ",
            "languagecode": "mi"
        },
        {
            "languageid": 84,
            "language": "Meiteilon Manipuri) ",
            "languagecode": "mni-Mtei"
        },
        {
            "languageid": 85,
            "language": "Mizo ",
            "languagecode": "lus"
        },
        {
            "languageid": 86,
            "language": "Mongolian ",
            "languagecode": "mn"
        },
        {
            "languageid": 87,
            "language": "Myanmar Burmese) ",
            "languagecode": "my"
        },
        {
            "languageid": 88,
            "language": "Nepali ",
            "languagecode": "ne"
        },
        {
            "languageid": 89,
            "language": "Norwegian ",
            "languagecode": "no"
        },
        {
            "languageid": 90,
            "language": "Nyanja Chichewa) ",
            "languagecode": "ny"
        },
        {
            "languageid": 91,
            "language": "Odia Oriya) ",
            "languagecode": "or"
        },
        {
            "languageid": 92,
            "language": "Oromo ",
            "languagecode": "om"
        },
        {
            "languageid": 93,
            "language": "Pashto ",
            "languagecode": "ps"
        },
        {
            "languageid": 94,
            "language": "Persian ",
            "languagecode": "fa"
        },
        {
            "languageid": 95,
            "language": "Polish ",
            "languagecode": "pl"
        },
        {
            "languageid": 96,
            "language": "Portuguese Portugal, Brazil) ",
            "languagecode": "pt"
        },
        {
            "languageid": 97,
            "language": "Punjabi ",
            "languagecode": "pa"
        },
        {
            "languageid": 98,
            "language": "Quechua ",
            "languagecode": "qu"
        },
        {
            "languageid": 99,
            "language": "Romanian ",
            "languagecode": "ro"
        },
        {
            "languageid": 100,
            "language": "Samoan ",
            "languagecode": "sm"
        },
        {
            "languageid": 101,
            "language": "Sanskrit ",
            "languagecode": "sa"
        },
        {
            "languageid": 102,
            "language": "Scots Gaelic ",
            "languagecode": "gd"
        },
        {
            "languageid": 103,
            "language": "Sepedi ",
            "languagecode": "nso"
        },
        {
            "languageid": 104,
            "language": "Serbian ",
            "languagecode": "sr"
        },
        {
            "languageid": 105,
            "language": "Sesotho ",
            "languagecode": "st"
        },
        {
            "languageid": 106,
            "language": "Shona ",
            "languagecode": "sn"
        },
        {
            "languageid": 107,
            "language": "Sindhi ",
            "languagecode": "sd"
        },
        {
            "languageid": 108,
            "language": "Sinhala Sinhalese) ",
            "languagecode": "si"
        },
        {
            "languageid": 109,
            "language": "Slovak ",
            "languagecode": "sk"
        },
        {
            "languageid": 110,
            "language": "Slovenian ",
            "languagecode": "sl"
        },
        {
            "languageid": 111,
            "language": "Somali ",
            "languagecode": "so"
        },
        {
            "languageid": 112,
            "language": "Sundanese ",
            "languagecode": "su"
        },
        {
            "languageid": 113,
            "language": "Swahili ",
            "languagecode": "sw"
        },
        {
            "languageid": 114,
            "language": "Swedish ",
            "languagecode": "sv"
        },
        {
            "languageid": 115,
            "language": "Tagalog Filipino) ",
            "languagecode": "tl"
        },
        {
            "languageid": 116,
            "language": "Tajik ",
            "languagecode": "tg"
        },
        {
            "languageid": 117,
            "language": "Tatar ",
            "languagecode": "tt"
        },
        {
            "languageid": 118,
            "language": "Thai ",
            "languagecode": "th"
        },
        {
            "languageid": 119,
            "language": "Tigrinya ",
            "languagecode": "ti"
        },
        {
            "languageid": 120,
            "language": "Tsonga ",
            "languagecode": "ts"
        },
        {
            "languageid": 121,
            "language": "Turkish ",
            "languagecode": "tr"
        },
        {
            "languageid": 122,
            "language": "Turkmen ",
            "languagecode": "tk"
        },
        {
            "languageid": 123,
            "language": "Twi Akan) ",
            "languagecode": "ak"
        },
        {
            "languageid": 124,
            "language": "Ukrainian ",
            "languagecode": "uk"
        },
        {
            "languageid": 125,
            "language": "Uyghur ",
            "languagecode": "ug"
        },
        {
            "languageid": 126,
            "language": "Uzbek ",
            "languagecode": "uz"
        },
        {
            "languageid": 127,
            "language": "Vietnamese ",
            "languagecode": "vi"
        },
        {
            "languageid": 128,
            "language": "Welsh ",
            "languagecode": "cy"
        },
        {
            "languageid": 129,
            "language": "Xhosa ",
            "languagecode": "xh"
        },
        {
            "languageid": 130,
            "language": "Yiddish ",
            "languagecode": "yi"
        },
        {
            "languageid": 131,
            "language": "Yoruba ",
            "languagecode": "yo"
        },
        {
            "languageid": 132,
            "language": "Zulu ",
            "languagecode": "zu"
        }
    ]

    const getLanguageDetails = (key, value) => {
        switch (key) {
          case 'id':
            return languageMaster.find(item => item.languageid === value);
          case 'code':
            return languageMaster.find(item => item.languagecode === value);
          case 'name':
            return languageMaster.find(item => item.language === value);
          case 'langarr':
            return languageMaster;
          default:
            return null;
        }
      };
      
      export default getLanguageDetails;

==> mypackage-mylang-1.0.4.tgz: package/index.js <==
const languageMaster =
    [
        {
            "languageid": 1,
            "language": "English",
            "languagecode": "en"
        },
        {
            "languageid": 2,
            "language": "Hindi",
            "languagecode": "hi"
        },
        {
            "languageid": 3,
            "language": "Marathi",
            "languagecode": "ar"
        },
        {
            "languageid": 4,
            "language": "Gujarati",
            "languagecode": "gu"
        },
        {
            "languageid": 5,
            "language": "Tamil",
            "languagecode": "ta"
        },
        {
            "languageid": 6,
            "language": "Bengali",
            "languagecode": "bn"
        },
        {
            "languageid": 7,
            "language": "Urdu",
            "languagecode": "ur"
        },
        {
            "languageid": 8,
            "language": "Spanish",
            "languagecode": "es"
        },
        {
            "languageid": 9,
            "language": "Marathi",
            "languagecode": "mr"
        },
        {
            "languageid": 10,
            "language": "Telugu",
            "languagecode": "te"
        },
        {
            "languageid": 11,
            "language": "French",
            "languagecode": "fr"
        },
        {
            "languageid": 12,
            "language": "Russian",
            "languagecode": "ru"
        },
        {
            "languageid": 13,
            "language": "Japanese",
            "languagecode": "ja"
        },
        {
            "languageid": 14,
            "language": "German",
            "languagecode": "de"
        },
        {
            "languageid": 15,
            "language": "Afrikaans ",
            "languagecode": "af"
        },
        {
            "languageid": 16,
            "language": "Albanian ",
            "languagecode": "sq"
        },
        {
            "languageid": 17,
            "language": "Amharic ",
            "languagecode": "am"
        },
        {
            "languageid": 18,
            "language": "Armenian ",
            "languagecode": "hy"
        },
        {
            "languageid": 19,
            "language": "Assamese ",
            "languagecode": "as"
        },
        {
            "languageid": 20,
            "language": "Aymara ",
            "languagecode": "ay"
        },
        {
            "languageid": 21,
            "language": "Azerbaijani ",
            "languagecode": "az"
        },
        {
            "languageid": 22,
            "language": "Bambara ",
            "languagecode": "bm"
        },
        {
            "languageid": 23,
            "language": "Basque ",
            "languagecode": "eu"
        },
        {
            "languageid": 24,
            "language": "Belarusian ",
            "languagecode": "be"
        },
        {
            "languageid": 25,
            "language": "Bhojpuri ",
            "languagecode": "bho"
        },
        {
            "languageid": 26,
            "language": "Bosnian ",
            "languagecode": "bs"
        },
        {
            "languageid": 27,
            "language": "Bulgarian ",
            "languagecode": "bg"
        },
        {
            "languageid": 28,
            "language": "Catalan ",
            "languagecode": "ca"
        },
        {
            "languageid": 29,
            "language": "Cebuano ",
            "languagecode": "ceb"
        },
        {
            "languageid": 30,
            "language": "Corsican ",
            "languagecode": "co"
        },
        {
            "languageid": 31,
            "language": "Croatian ",
            "languagecode": "hr"
        },
        {
            "languageid": 32,
            "language": "Czech ",
            "languagecode": "cs"
        },
        {
            "languageid": 33,
            "language": "Danish ",
            "languagecode": "da"
        },
        {
            "languageid": 34,
            "language": "Dhivehi ",
            "languagecode": "dv"
        },
        {
            "languageid": 35,
            "language": "Dogri ",
            "languagecode": "doi"
        },
        {
            "languageid": 36,
            "language": "Dutch ",
            "languagecode": "nl"
        },
        {
            "languageid": 37,
            "language": "Esperanto ",
            "languagecode": "eo"
        },
        {
            "languageid": 38,
            "language": "Estonian ",
            "languagecode": "et"
        },
        {
            "languageid": 39,
            "language": "Ewe ",
            "languagecode": "ee"
        },
        {
            "languageid": 40,
            "language": "Filipino Tagalog) ",
            "languagecode": "fil"
        },
        {
            "languageid": 41,
            "language": "Finnish ",
            "languagecode": "fi"
        },
        {
            "languageid": 42,
            "language": "Frisian ",
            "languagecode": "fy"
        },
        {
            "languageid": 43,
            "language": "Galician ",
            "languagecode": "gl"
        },
        {
            "languageid": 44,
            "language": "Georgian ",
            "languagecode": "ka"
        },
        {
            "languageid": 45,
            "language": "Greek ",
            "languagecode": "el"
        },
        {
            "languageid": 46,
            "language": "Guarani ",
            "languagecode": "gn"
        },
        {
            "languageid": 47,
            "language": "Haitian Creole ",
            "languagecode": "ht"
        },
        {
            "languageid": 48,
            "language": "Hausa ",
            "languagecode": "ha"
        },
        {
            "languageid": 49,
            "language": "Hawaiian ",
            "languagecode": "haw"
        },
        {
            "languageid": 50,
            "language": "Hebrew ",
            "languagecode": "he or iw"
        },
        {
            "languageid": 51,
            "language": "Hmong ",
            "languagecode": "hmn"
        },
        {
            "languageid": 52,
            "language": "Hungarian ",
            "languagecode": "hu"
        },
        {
            "languageid": 53,
            "language": "Icelandic ",
            "languagecode": "is"
        },
        {
            "languageid": 54,
            "language": "Igbo ",
            "languagecode": "ig"
        },
        {
            "languageid": 55,
            "language": "Ilocano ",
            "languagecode": "ilo"
        },
        {
            "languageid": 56,
            "language": "Indonesian ",
            "languagecode": "id"
        },
        {
            "languageid": 57,
            "language": "Irish ",
            "languagecode": "ga"
        },
        {
            "languageid": 58,
            "language": "Italian ",
            "languagecode": "it"
        },
        {
            "languageid": 59,
            "language": "Javanese ",
            "languagecode": "jv or jw"
        },
        {
            "languageid": 60,
            "language": "Kannada ",
            "languagecode": "kn"
        },
        {
            "languageid": 61,
            "language": "Kazakh ",
            "languagecode": "kk"
        },
        {
            "languageid": 62,
            "language": "Khmer ",
            "languagecode": "km"
        },
        {
            "languageid": 63,
            "language": "Kinyarwanda ",
            "languagecode": "rw"
        },
        {
            "languageid": 64,
            "language": "Konkani ",
            "languagecode": "gom"
        },
        {
            "languageid": 65,
            "language": "Korean ",
            "languagecode": "ko"
        },
        {
            "languageid": 66,
            "language": "Krio ",
            "languagecode": "kri"
        },
        {
            "languageid": 67,
            "language": "Kurdish ",
            "languagecode": "ku"
        },
        {
            "languageid": 68,
            "language": "Kurdish Sorani) ",
            "languagecode": "ckb"
        },
        {
            "languageid": 69,
            "language": "Kyrgyz ",
            "languagecode": "ky"
        },
        {
            "languageid": 70,
            "language": "Lao ",
            "languagecode": "lo"
        },
        {
            "languageid": 71,
            "language": "Latin ",
            "languagecode": "la"
        },
        {
            "languageid": 72,
            "language": "Latvian ",
            "languagecode": "lv"
        },
        {
            "languageid": 73,
            "language": "Lingala ",
            "languagecode": "ln"
        },
        {
            "languageid": 74,
            "language": "Lithuanian ",
            "languagecode": "lt"
        },
        {
            "languageid": 75,
            "language": "Luganda ",
            "languagecode": "lg"
        },
        {
            "languageid": 76,
            "language": "Luxembourgish ",
            "languagecode": "lb"
        },
        {
            "languageid": 77,
            "language": "Macedonian ",
            "languagecode": "mk"
        },
        {
            "languageid": 78,
            "language": "Maithili ",
            "languagecode": "mai"
        },
        {
            "languageid": 79,
            "language": "Malagasy ",
            "languagecode": "mg"
        },
        {
            "languageid": 80,
            "language": "Malay ",
            "languagecode": "ms"
        },
        {
            "languageid": 81,
            "language": "Malayalam ",
            "languagecode": "ml"
        },
        {
            "languageid": 82,
            "language": "Maltese ",
            "languagecode": "mt"
        },
        {
            "languageid": 83,
            "language": "Maori ",
            "languagecode": "mi"
        },
        {
            "languageid": 84,
            "language": "Meiteilon Manipuri) ",
            "languagecode": "mni-Mtei"
        },
        {
            "languageid": 85,
            "language": "Mizo ",
            "languagecode": "lus"
        },
        {
            "languageid": 86,
            "language": "Mongolian ",
            "languagecode": "mn"
        },
        {
            "languageid": 87,
            "language": "Myanmar Burmese) ",
            "languagecode": "my"
        },
        {
            "languageid": 88,
            "language": "Nepali ",
            "languagecode": "ne"
        },
        {
            "languageid": 89,
            "language": "Norwegian ",
            "languagecode": "no"
        },
        {
            "languageid": 90,
            "language": "Nyanja Chichewa) ",
            "languagecode": "ny"
        },
        {
            "languageid": 91,
            "language": "Odia Oriya) ",
            "languagecode": "or"
        },
        {
            "languageid": 92,
            "language": "Oromo ",
            "languagecode": "om"
        },
        {
            "languageid": 93,
            "language": "Pashto ",
            "languagecode": "ps"
        },
        {
            "languageid": 94,
            "language": "Persian ",
            "languagecode": "fa"
        },
        {
            "languageid": 95,
            "language": "Polish ",
            "languagecode": "pl"
        },
        {
            "languageid": 96,
            "language": "Portuguese Portugal, Brazil) ",
            "languagecode": "pt"
        },
        {
            "languageid": 97,
            "language": "Punjabi ",
            "languagecode": "pa"
        },
        {
            "languageid": 98,
            "language": "Quechua ",
            "languagecode": "qu"
        },
        {
            "languageid": 99,
            "language": "Romanian ",
            "languagecode": "ro"
        },
        {
            "languageid": 100,
            "language": "Samoan ",
            "languagecode": "sm"
        },
        {
            "languageid": 101,
            "language": "Sanskrit ",
            "languagecode": "sa"
        },
        {
            "languageid": 102,
            "language": "Scots Gaelic ",
            "languagecode": "gd"
        },
        {
            "languageid": 103,
            "language": "Sepedi ",
            "languagecode": "nso"
        },
        {
            "languageid": 104,
            "language": "Serbian ",
            "languagecode": "sr"
        },
        {
            "languageid": 105,
            "language": "Sesotho ",
            "languagecode": "st"
        },
        {
            "languageid": 106,
            "language": "Shona ",
            "languagecode": "sn"
        },
        {
            "languageid": 107,
            "language": "Sindhi ",
            "languagecode": "sd"
        },
        {
            "languageid": 108,
            "language": "Sinhala Sinhalese) ",
            "languagecode": "si"
        },
        {
            "languageid": 109,
            "language": "Slovak ",
            "languagecode": "sk"
        },
        {
            "languageid": 110,
            "language": "Slovenian ",
            "languagecode": "sl"
        },
        {
            "languageid": 111,
            "language": "Somali ",
            "languagecode": "so"
        },
        {
            "languageid": 112,
            "language": "Sundanese ",
            "languagecode": "su"
        },
        {
            "languageid": 113,
            "language": "Swahili ",
            "languagecode": "sw"
        },
        {
            "languageid": 114,
            "language": "Swedish ",
            "languagecode": "sv"
        },
        {
            "languageid": 115,
            "language": "Tagalog Filipino) ",
            "languagecode": "tl"
        },
        {
            "languageid": 116,
            "language": "Tajik ",
            "languagecode": "tg"
        },
        {
            "languageid": 117,
            "language": "Tatar ",
            "languagecode": "tt"
        },
        {
            "languageid": 118,
            "language": "Thai ",
            "languagecode": "th"
        },
        {
            "languageid": 119,
            "language": "Tigrinya ",
            "languagecode": "ti"
        },
        {
            "languageid": 120,
            "language": "Tsonga ",
            "languagecode": "ts"
        },
        {
            "languageid": 121,
            "language": "Turkish ",
            "languagecode": "tr"
        },
        {
            "languageid": 122,
            "language": "Turkmen ",
            "languagecode": "tk"
        },
        {
            "languageid": 123,
            "language": "Twi Akan) ",
            "languagecode": "ak"
        },
        {
            "languageid": 124,
            "language": "Ukrainian ",
            "languagecode": "uk"
        },
        {
            "languageid": 125,
            "language": "Uyghur ",
            "languagecode": "ug"
        },
        {
            "languageid": 126,
            "language": "Uzbek ",
            "languagecode": "uz"
        },
        {
            "languageid": 127,
            "language": "Vietnamese ",
            "languagecode": "vi"
        },
        {
            "languageid": 128,
            "language": "Welsh ",
            "languagecode": "cy"
        },
        {
            "languageid": 129,
            "language": "Xhosa ",
            "languagecode": "xh"
        },
        {
            "languageid": 130,
            "language": "Yiddish ",
            "languagecode": "yi"
        },
        {
            "languageid": 131,
            "language": "Yoruba ",
            "languagecode": "yo"
        },
        {
            "languageid": 132,
            "language": "Zulu ",
            "languagecode": "zu"
        }
    ]

const getLanguageDetails = (key, value) => {
    switch (key) {
        case 'id':
            const languageById = languageMaster.find(item => item.languageid === value);
            return languageById ? languageById.language : null;

        case 'code':
            const languageByCode = languageMaster.find(item => item.languagecode === value);
            return languageByCode ? languageByCode.language : null;

        case 'name':
            return languageMaster.find(item => item.language === value);
            
        case 'langarr':
            return languageMaster;
        default:
            return null;
    }
};

export default getLanguageDetails;
